@@ -509,12 +509,12 @@ sum_method <- function(model, software) {
   if (software == 'nonmem') {
     x <- model %>% 
       dplyr::filter(.$subroutine %in% c('sim', 'est')) %>% 
-      dplyr::filter(stringr::str_detect(.$code, 'METH|NSUB'))
+      dplyr::filter(stringr::str_detect(.$code, '(?<!RAN)METH|NSUB'))
     
     if (nrow(x) == 0) return(sum_tpl('method', 'na'))
     
     x %>% 
-      dplyr::mutate(value = stringr::str_match(.$code, 'METH[OD]*\\s*=\\s*([^\\s]+)')[, 2],
+      dplyr::mutate(value = stringr::str_match(.$code, '(?<!RAN)METH[OD]*\\s*=\\s*([^\\s]+)')[, 2],
                     inter = stringr::str_detect(.$code, '\\sINTER'),
                     lapl  = stringr::str_detect(.$code, '\\sLAPLA'),
                     like  = stringr::str_detect(.$code, '\\sLIKE')) %>% 
